\name{smrs4}
\alias{smrs4}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Computes a 4-state parametric additive relative survival semi-Markov model by likelihood maximization
}
\description{
The 4-state SMRS model includes an initial state (X=1), a transient state (X=2) and two absorbing states including death (X=3, and X=4 for observed death regardless of cause). The possible transitions are: 1->2, 1->3, 1->4, 2->3 and 2->4. In additive relative survival analysis, the observed mortality hazard (X=4) is assumed to be the sum of two components: the expected population mortality (X=P) and the excess mortality related to the disease under study (X=E). The expected population mortality hazard (X=P) can be obtained from the death rates provided by life tables of statistical national institutes. These tables indicate the proportion of people dead in a calendar year stratified by birthdate and gender. The instantaneous hazard functions for times to death related to the disease (X=E) are modelled here using parametric distributions. 
}
\usage{
smrs4(t1, t2, sequence, dist, cuts.12=NULL, cuts.13=NULL, cuts.14=NULL, 
cuts.23=NULL, cuts.24=NULL, ini.base.12=NULL, ini.base.13=NULL, ini.base.14=NULL, 
ini.base.23=NULL, ini.base.24=NULL, cov.12=NULL, init.cov.12=NULL, names.12=NULL, 
cov.13=NULL, init.cov.13=NULL, names.13=NULL, cov.14=NULL, init.cov.14=NULL, 
names.14=NULL, cov.23=NULL, init.cov.23=NULL, names.23=NULL, cov.24=NULL, 
init.cov.24=NULL, names.24=NULL, p.age, p.sex, p.year, p.rate.table, 
conf.int=TRUE, silent=TRUE, precision=10^(-6), maxiter=10^4)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{t1}{a numeric vector with the observed times in days from baseline to the first transition (X=2 or direct transition to X=3 or X=4) or to the right-censoring in X=1.}
  \item{t2}{a numeric vector with the observed times in days from baseline to the second transition or to the right censoring in X=2. \code{NA} for individuals right-censored in X=1 or individuals who directly transited from X=1 to X=3 or to X=1 to X=4.}
  \item{sequence}{a numeric vector with the sequence of observed states. Six possible values are allowed: 1 (individual right-censored in X=1), 12 (individual right-censored in X=2), 13 (individual who directly transited from X=1 to X=3), 14 (individual who directly transited from X=1 to X=4), 123 (individual who transited from X=1 to X=3 through X=2), 124 (individual who transited from X=1 to X=4 through X=2).}
  \item{dist}{a character vector with five arguments describing respectively the distributions of duration time for transitions 1->2, 1->3, 1->4, 2->3 and 2->4. Arguments allowed are \code{"E"} for Exponential distribution, \code{"PE"} for the piecewise exponential distribution, \code{"W"} for Weibull distribution or \code{"WG"} for Generalized Weibull distribution.}
  \item{cuts.12}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=1 to X=2. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.13}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=1 to X=3. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.14}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=1 to X=4. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.23}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=2 to X=3. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.24}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=2 to X=4. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{ini.base.12}{a numeric vector of initial logarithm values for parameters of distribution from X=1 to X=2. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.13}{a numeric vector of initial logarithm values for parameters of distribution from X=1 to X=3. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.14}{a numeric vector of initial logarithm values for parameters of distribution from X=1 to X=4. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.23}{a numeric vector of initial logarithm values for parameters of distribution from X=2 to X=3. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.24}{a numeric vector of initial logarithm values for parameters of distribution from X=2 to X=4. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{cov.12}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=1 to X=2.}
  \item{init.cov.12}{a numeric vector of initial values for regression coefficients associated to \code{cov.12}. Default initial value is 0 for all parameters.}
  \item{names.12}{a character vector with name of explicative variables associated to \code{cov.12} (optional).}
  \item{cov.13}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=1 to X=3.}
  \item{init.cov.13}{a numeric vector of initial values for regression coefficients associated to \code{cov.13}. Default initial value is 0 for all parameters.}
  \item{names.13}{a character vector with name of explicative variables associated to \code{cov.13} (optional).}
  \item{cov.14}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=1 to X=3.}
  \item{init.cov.14}{a numeric vector of initial values for regression coefficients associated to \code{cov.14}. Default initial value is 0 for all parameters.}
  \item{names.14}{a character vector with name of explicative variables associated to \code{cov.14} (optional).}
  \item{cov.23}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=2 to X=3.}
  \item{init.cov.23}{a numeric vector of initial values for regression coefficients associated to \code{cov.23}. Default initial value is 0 for all parameters.}
  \item{names.23}{a character vector with name of explicative variables associated to \code{cov.23} (optional).}
  \item{cov.24}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=2 to X=3.}
  \item{init.cov.24}{a numeric vector of initial values for regression coefficients associated to \code{cov.24}. Default initial value is 0 for all parameters.}
  \item{names.24}{a character vector with name of explicative variables associated to \code{cov.24} (optional).}
  \item{p.age}{a numeric vector with the ages in days at baseline (X=1).}
  \item{p.sex}{a character vector with the gender: \code{male} or \code{female}.}
  \item{p.year}{a numeric vector with entry date in the study in the date format, i.e. in number of days since 01.01.1960.}
  \item{p.rate.table}{a table of event rates, organized as a \code{ratetable} object.}
  \item{conf.int}{a logical value specifying if the pointwise confidence intervals for parameters and the variance-covariance matrix should be returned. Default is \code{TRUE}.}
  \item{silent}{a logical value specifying if the log-likelihood value should be returned at each iteration. Default is \code{TRUE}, which corresponds to silent mode (no display).}
  \item{precision}{a numeric positive value indicating the required precision for the log-likelihood maximization between each iteration. Default is \eqn{10^{-6}}.}
  \item{maxiter}{a numeric positive value indicating the maximum number of iterations for the log-likelihood maximization. Default is \eqn{10^{4}}.}
 }

\details{
Hazard functions available are:
\tabular{rl}{
\code{Exponential} distribution \tab \eqn{\lambda(t)=1/\sigma} \cr											
\code{Weibull} distribution \tab \eqn{\lambda(t)=\nu(\frac{1}{\sigma})^{\nu}t^{\nu-1}} \cr
\code{Generalized Weibull} distribution \tab \eqn{\lambda(t)=\frac{1}{\theta}\left(1+\left(\frac{t}{\sigma}\right)^{\nu}\right)^{\frac{1}{\theta}-1} \nu\left(\frac{1}{\sigma}\right)^{\nu} t^{\nu-1}}
}
with \eqn{\sigma}, \eqn{\nu},and \eqn{\theta>0}. The parameter \eqn{\sigma} varies for each interval when the distribution is piecewise Exponential. To avoid negative values, these parameters are exponentiated in the model. Therefore, the user must initialize logarithm values of parameters in \code{ini.base.12}, \code{ini.base.13}, \code{ini.base.14}, \code{ini.base.23} and \code{ini.base.24}. Moreover, the estimated values also correspond to the logarithms. Maximization of the log-likelihood function is performed using the algorithms of Nelder and Mead (\code{optim} function). Works only with ratetables that are split by age, sex and year. 
}
\value{
\item{Table}{a data.frame containing the parameter estimations of the model (\code{Estimate}). When the option \code{conf.int=TRUE} is specified, this data.frame includes three additional columns: the Standard Errors of parameters (\code{Std.Error}), the value of the Wald statistic (\code{t.value}), and the p-value for the Wald test (\code{Pr(>|t|)}).}
\item{CovarianceMatrix}{a data.frame corresponding to variance-covariance matrix of the estimated model.}
\item{LogLik}{a numeric value corresponding to the log-likelihood of the estimated model.}
\item{AIC}{a numeric value corresponding to the Akaike Information Criterion of the estimated model.}
}

\references{
Gillaizeau F, Dantan E, Giral M, Foucher Y. A multistate additive relative survival semi-Markov model. Manuscript submitted. 2015.

Pohar M., Stare J. (2006) "Relative survival analysis in R." Computer Methods and Programs in Biomedicine, 81: 272-278
}
\author{
Yohann Foucher <Yohann.Foucher@univ-nantes.fr> and

Florence Gillaizeau <Florence.Gillaizeau@univ-nantes.fr>
}

\examples{

# import the observed data
# (X=1 corresponds to initial state with a functioning graft, X=2 to acute rejection episode, 
# X=3 to return to dialysis, X=4 to death with a functioning graft)

data(dataDIVAT)

# A subgroup analysis to reduce the time needed for this example

dataDIVAT$id<-c(1:nrow(dataDIVAT))
set.seed(2)
dataDIVATsample<-dataDIVAT[dataDIVAT$id \%in\% sample(dataDIVAT$id, trunc(nrow(dataDIVAT)/10),
 replace = FALSE),]

# import the expected mortality rates

data(fr.ratetable)

# 4-state parametric additive relative survival semi-Markov model including one 
# explicative variable ('z') on all transitions

# Note: a semi-Markovian process with sojourn times exponentially distributed
# is a time-homogeneous Markov process

smrs4(t1=dataDIVATsample$time1,
  t2=dataDIVATsample$time2,
  sequence=dataDIVATsample$trajectory,
  dist=c("E","E","E","E","E"),
  cuts.12=NULL,
  cuts.13=NULL,
  cuts.14=NULL,
  cuts.23=NULL,
  cuts.24=NULL,
  ini.base.12=c(8.34),
  ini.base.13=c(10.44),
  ini.base.14=c(10.70),
  ini.base.23=c(9.43),
  ini.base.24=c(11.11),
  cov.12=dataDIVATsample$z,
  init.cov.12=c(0.04),
  names.12=c("beta12_z") ,
  cov.13=dataDIVATsample$z,
  init.cov.13=c(1.02),
  names.13=c("beta13_z") ,
  cov.14=dataDIVATsample$z,
  init.cov.14=c(1.04),
  names.14=c("beta1E_z") ,
  cov.23=dataDIVATsample$z,
  init.cov.23=c(0.94),
  names.23=c("beta23_z") ,
  cov.24=dataDIVATsample$z,
  init.cov.24=c(0.30),
  names.24=c("beta2E_z"),
  p.age=dataDIVATsample$ageR*365.24,
  p.sex=dataDIVATsample$sexR,
  p.year=as.date(paste("01","01",dataDIVATsample$year.tx),order = "mdy"),
  p.rate.table=fr.ratetable,
  conf.int=TRUE,
  silent=FALSE,
  precision=0.001,
  maxiter=1000)

}

\keyword{ semi-Markov }
\keyword{ multistate }
\keyword{ relative survival }